Crate rex_typesystem

Crate rex_typesystem 

Hindley-Milner type system with parametric polymorphism, type classes, and ADTs. The goal is to provide a reusable library for building typing environments for Rex. Features:

  • Type variables, type constructors, function and tuple types.
  • Schemes with quantified variables and class constraints.
  • Type classes with superclass relationships and instance resolution.
  • Basic ADTs (List, Result, Option) and numeric/string primitives in the prelude.
  • Utilities to register additional function/type declarations (e.g. (-), (/)).

Modules

error
inference
prelude
types
typesystem
Core type system implementation for Rex.
unification