Module types

Module types 

Structs

AdtDecl
A type declaration for an algebraic data type.
AdtParam
A named type parameter for an ADT (e.g. a in List a).
AdtVariant
A single ADT variant with zero or more constructor arguments.
Class
ClassEnv
Instance
Predicate
Scheme
Type
TypeEnv
TypeVar
TypedExpr

Enums

BuiltinTypeId
TypeConst
TypeKind
TypedExprKind

Traits

RexAdt
Rust-side declaration metadata for a type represented as a Rex ADT.
RexType
Rust-side type metadata for values that can appear at a Rex boundary.
Types

Functions

collect_adts_in_types
Collect all user-defined ADT constructors referenced by the provided types.
order_adt_family
Order a family of algebraic data type declarations for registration.

Type Aliases

TypeVarId