Module typesystem

Module typesystem 

Core type system implementation for Rex.

Re-exports

pub use crate::unification::Subst;
pub use crate::unification::compose_subst;
pub use crate::unification::unify;

Structs

ClassInfo
Semantic information about a type class declaration, derived from Rex source.
ClassMethodInfo
PreparedInstanceDecl
TypeSystem
TypeSystemLimits
TypeVarSupply

Functions

entails
generalize
Turn a monotype typ (plus constraints preds) into a polymorphic Scheme by quantifying over the type variables not free in env.
instantiate