Structs
- AdtDecl
- A type declaration for an algebraic data type.
- AdtParam
- A named type parameter for an ADT (e.g.
ainList a). - AdtVariant
- A single ADT variant with zero or more constructor arguments.
- Class
- Class
Env - Instance
- Predicate
- Scheme
- Type
- TypeEnv
- TypeVar
- Typed
Expr
Enums
Traits
- RexAdt
- Rust-side declaration metadata for a type represented as a Rex ADT.
- RexType
- Rust-side type metadata for values that can appear at a Rex boundary.
- Types
Functions
- collect_
adts_ in_ types - Collect all user-defined ADT constructors referenced by the provided types.
- order_
adt_ family - Order a family of algebraic data type declarations for registration.