Core type system implementation for Rex.
Re-exports
pub use crate::unification::Subst;pub use crate::unification::compose_subst;pub use crate::unification::unify;
Structs
- Class
Info - Semantic information about a type class declaration, derived from Rex source.
- Class
Method Info - Prepared
Instance Decl - Type
System - Type
System Limits - Type
VarSupply
Functions
- entails
- generalize
- Turn a monotype
typ(plus constraintspreds) into a polymorphicSchemeby quantifying over the type variables not free inenv. - instantiate